Retrieve a bulk report of all the rankings or for specific sites.
ssar_bulk_rankings(
date = Sys.Date() - 1,
siteid = NULL,
ranktype = "highest",
engines = c("google", "bing"),
currentlytracked = TRUE,
crawledkeywords = TRUE,
subdomain = Sys.getenv("SSAR_SUBDOMAIN"),
apikey = Sys.getenv("SSAR_APIKEY")
)The date being requested (required) in 'YYYY-MM-DD' format. Default is set to yesterday.
The site id. If not provided then all sites will be returned. Comma separated list of specific site IDs, default is all sites.
This argument changes the call between getting the highest ranks for the keywords for the date with the value highest, or getting all the ranks for each engine for a keyword for a date with the value all. Defaults to highest if not provided.
This argument lets you choose which search engines to include in the export, defaulting to Google and Bing. Engines can be passed in comma separated to get multiple.
This argument will cause the API to ouptput only keywords which currently have tracking on at the time the API request is generated.
This argument causes the API to only include output for keywords that were crawled on the date argument provided.
The account subdomain
The api key from the account
The dataframe with all keywords ranking information for the requested date