powered by
Retrieve a table including metadata for all the sites in a particular project
ssar_rankings( keywordid = NULL, fromdate = NULL, todate = NULL, start = 0, results = 100, subdomain = Sys.getenv("SSAR_SUBDOMAIN"), apikey = Sys.getenv("SSAR_APIKEY") )
The keyword id (required)
Default is 100 most recent results (optional) Format is a string YYYY-MM-DD
Default is most recent ranking day (optional) Format is a string YYYY-MM-DD
The default is 0 (zero indexed). The starting result for paginated requests
The default is 100
The account subdomain
The api key from the account
A dataframe of all rankings within a defined date range for a specific keyword
# NOT RUN { ssar_rankings(keywordid = {keyword_id}, #replace with your keyword_id fromdate = '2021-01-01', todate = '2021-04-01') # } # NOT RUN { # }
Run the code above in your browser using DataLab