Learn R Programming

statsearchanalyticsr (version 0.1.4)

ssar_sites: Get Sites

Description

Retrieve a table of all the sites and metadata in a specified project

Usage

ssar_sites(
  projectid = NULL,
  start = NULL,
  results = 100,
  subdomain = Sys.getenv("SSAR_SUBDOMAIN"),
  apikey = Sys.getenv("SSAR_APIKEY")
)

Arguments

projectid

The project id. If not provided then all sites will be returned.

start

If more than results are available use start as pagination. Index starts at 0 (default).

results

Default is 100. Max is 5000.

subdomain

The account subdomain

apikey

The api key from the account

Value

A table of the site information within a project

Examples

Run this code
# NOT RUN {
ssar_sites(projectid = {project_id}, #replace with your project id
           results = 300)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab