powered by
Retrieve a table of all the sites and metadata in a specified project
ssar_sites( projectid = NULL, start = NULL, results = 100, subdomain = Sys.getenv("SSAR_SUBDOMAIN"), apikey = Sys.getenv("SSAR_APIKEY") )
The project id. If not provided then all sites will be returned.
If more than results are available use start as pagination. Index starts at 0 (default).
results
start
Default is 100. Max is 5000.
The account subdomain
The api key from the account
A table of the site information within a project
# NOT RUN { ssar_sites(projectid = {project_id}, #replace with your project id results = 300) # } # NOT RUN { # }
Run the code above in your browser using DataLab